# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ApplicationStateTransitionEvent(object):

    def __init__(self, timestamp_unixtime_ms=None, event_id=None, source_message_id=None, session_id=None, session_uuid=None, custom_attributes=None, location=None, device_current_state=None, successfully_closed=None, is_first_run=None, is_upgrade=None, push_notification_payload=None, application_transition_type=None):
        """
        ApplicationStateTransitionEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'successfully_closed': 'bool',
            'is_first_run': 'bool',
            'is_upgrade': 'bool',
            'push_notification_payload': 'str',
            'application_transition_type': 'str'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'successfully_closed': 'successfully_closed',
            'is_first_run': 'is_first_run',
            'is_upgrade': 'is_upgrade',
            'push_notification_payload': 'push_notification_payload',
            'application_transition_type': 'application_transition_type'
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self._custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._successfully_closed = successfully_closed
        self._is_first_run = is_first_run
        self._is_upgrade = is_upgrade
        self._push_notification_payload = push_notification_payload
        self._application_transition_type = application_transition_type

    @classmethod
    def create_install_event(cls):
        event = cls()
        event.application_transition_type = 'application_initialized'
        event.is_first_run = True
        event.is_upgrade = False
        return event

    @classmethod
    def create_upgrade_event(cls):
        event = cls()
        event.application_transition_type = 'application_initialized'
        event.is_first_run = False
        event.is_upgrade = True
        return event

    @classmethod
    def create_foreground_event(cls):
        event = cls()
        event.application_transition_type = 'application_foreground'
        return event

    @classmethod
    def create_background_event(cls):
        event = cls()
        event.application_transition_type = 'application_background'
        return event

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this ApplicationStateTransitionEvent.


        :return: The timestamp_unixtime_ms of this ApplicationStateTransitionEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this ApplicationStateTransitionEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this ApplicationStateTransitionEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this ApplicationStateTransitionEvent.


        :return: The event_id of this ApplicationStateTransitionEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this ApplicationStateTransitionEvent.


        :param event_id: The event_id of this ApplicationStateTransitionEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this ApplicationStateTransitionEvent.


        :return: The source_message_id of this ApplicationStateTransitionEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this ApplicationStateTransitionEvent.


        :param source_message_id: The source_message_id of this ApplicationStateTransitionEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this ApplicationStateTransitionEvent.


        :return: The session_id of this ApplicationStateTransitionEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this ApplicationStateTransitionEvent.


        :param session_id: The session_id of this ApplicationStateTransitionEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this ApplicationStateTransitionEvent.


        :return: The session_uuid of this ApplicationStateTransitionEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this ApplicationStateTransitionEvent.


        :param session_uuid: The session_uuid of this ApplicationStateTransitionEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this ApplicationStateTransitionEvent.


        :return: The custom_attributes of this ApplicationStateTransitionEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this ApplicationStateTransitionEvent.


        :param custom_attributes: The custom_attributes of this ApplicationStateTransitionEvent.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this ApplicationStateTransitionEvent.


        :return: The location of this ApplicationStateTransitionEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this ApplicationStateTransitionEvent.


        :param location: The location of this ApplicationStateTransitionEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this ApplicationStateTransitionEvent.


        :return: The device_current_state of this ApplicationStateTransitionEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this ApplicationStateTransitionEvent.


        :param device_current_state: The device_current_state of this ApplicationStateTransitionEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def successfully_closed(self):
        """
        Gets the successfully_closed of this ApplicationStateTransitionEvent.


        :return: The successfully_closed of this ApplicationStateTransitionEvent.
        :rtype: bool
        """
        return self._successfully_closed

    @successfully_closed.setter
    def successfully_closed(self, successfully_closed):
        """
        Sets the successfully_closed of this ApplicationStateTransitionEvent.


        :param successfully_closed: The successfully_closed of this ApplicationStateTransitionEvent.
        :type: bool
        """

        self._successfully_closed = successfully_closed

    @property
    def is_first_run(self):
        """
        Gets the is_first_run of this ApplicationStateTransitionEvent.


        :return: The is_first_run of this ApplicationStateTransitionEvent.
        :rtype: bool
        """
        return self._is_first_run

    @is_first_run.setter
    def is_first_run(self, is_first_run):
        """
        Sets the is_first_run of this ApplicationStateTransitionEvent.


        :param is_first_run: The is_first_run of this ApplicationStateTransitionEvent.
        :type: bool
        """

        self._is_first_run = is_first_run

    @property
    def is_upgrade(self):
        """
        Gets the is_upgrade of this ApplicationStateTransitionEvent.


        :return: The is_upgrade of this ApplicationStateTransitionEvent.
        :rtype: bool
        """
        return self._is_upgrade

    @is_upgrade.setter
    def is_upgrade(self, is_upgrade):
        """
        Sets the is_upgrade of this ApplicationStateTransitionEvent.


        :param is_upgrade: The is_upgrade of this ApplicationStateTransitionEvent.
        :type: bool
        """

        self._is_upgrade = is_upgrade

    @property
    def push_notification_payload(self):
        """
        Gets the push_notification_payload of this ApplicationStateTransitionEvent.


        :return: The push_notification_payload of this ApplicationStateTransitionEvent.
        :rtype: str
        """
        return self._push_notification_payload

    @push_notification_payload.setter
    def push_notification_payload(self, push_notification_payload):
        """
        Sets the push_notification_payload of this ApplicationStateTransitionEvent.


        :param push_notification_payload: The push_notification_payload of this ApplicationStateTransitionEvent.
        :type: str
        """

        self._push_notification_payload = push_notification_payload

    @property
    def application_transition_type(self):
        """
        Gets the application_transition_type of this ApplicationStateTransitionEvent.


        :return: The application_transition_type of this ApplicationStateTransitionEvent.
        :rtype: str
        """
        return self._application_transition_type

    @application_transition_type.setter
    def application_transition_type(self, application_transition_type):
        """
        Sets the application_transition_type of this ApplicationStateTransitionEvent.


        :param application_transition_type: The application_transition_type of this ApplicationStateTransitionEvent.
        :type: str
        """
        allowed_values = ["unknown", "application_initialized", "application_exit", "application_background", "application_foreground"]
        if application_transition_type not in allowed_values:
            raise ValueError(
                "Invalid value for `application_transition_type` ({0}), must be one of {1}"
                .format(application_transition_type, allowed_values)
            )

        self._application_transition_type = application_transition_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class DeviceCurrentState(object):

    def __init__(self, time_since_start_ms=None, battery_level=None, data_connection_type=None, data_connection_type_detail=None, gps_state=None, total_system_memory_usage_bytes=None, disk_space_free_bytes=None, cpu=None, system_memory_available_bytes=None, system_memory_low=None, system_memory_threshold_bytes=None, application_memory_available_bytes=None, application_memory_max_bytes=None, application_memory_total_bytes=None, device_orientation=None, status_bar_orientation=None):
        """
        DeviceCurrentState - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'time_since_start_ms': 'int',
            'battery_level': 'float',
            'data_connection_type': 'str',
            'data_connection_type_detail': 'str',
            'gps_state': 'bool',
            'total_system_memory_usage_bytes': 'int',
            'disk_space_free_bytes': 'int',
            'cpu': 'str',
            'system_memory_available_bytes': 'float',
            'system_memory_low': 'bool',
            'system_memory_threshold_bytes': 'float',
            'application_memory_available_bytes': 'float',
            'application_memory_max_bytes': 'float',
            'application_memory_total_bytes': 'float',
            'device_orientation': 'str',
            'status_bar_orientation': 'str'
        }

        self.attribute_map = {
            'time_since_start_ms': 'time_since_start_ms',
            'battery_level': 'battery_level',
            'data_connection_type': 'data_connection_type',
            'data_connection_type_detail': 'data_connection_type_detail',
            'gps_state': 'gps_state',
            'total_system_memory_usage_bytes': 'total_system_memory_usage_bytes',
            'disk_space_free_bytes': 'disk_space_free_bytes',
            'cpu': 'cpu',
            'system_memory_available_bytes': 'system_memory_available_bytes',
            'system_memory_low': 'system_memory_low',
            'system_memory_threshold_bytes': 'system_memory_threshold_bytes',
            'application_memory_available_bytes': 'application_memory_available_bytes',
            'application_memory_max_bytes': 'application_memory_max_bytes',
            'application_memory_total_bytes': 'application_memory_total_bytes',
            'device_orientation': 'device_orientation',
            'status_bar_orientation': 'status_bar_orientation'
        }

        self._time_since_start_ms = time_since_start_ms
        self._battery_level = battery_level
        self._data_connection_type = data_connection_type
        self._data_connection_type_detail = data_connection_type_detail
        self._gps_state = gps_state
        self._total_system_memory_usage_bytes = total_system_memory_usage_bytes
        self._disk_space_free_bytes = disk_space_free_bytes
        self._cpu = cpu
        self._system_memory_available_bytes = system_memory_available_bytes
        self._system_memory_low = system_memory_low
        self._system_memory_threshold_bytes = system_memory_threshold_bytes
        self._application_memory_available_bytes = application_memory_available_bytes
        self._application_memory_max_bytes = application_memory_max_bytes
        self._application_memory_total_bytes = application_memory_total_bytes
        self._device_orientation = device_orientation
        self._status_bar_orientation = status_bar_orientation

    @property
    def time_since_start_ms(self):
        """
        Gets the time_since_start_ms of this DeviceCurrentState.


        :return: The time_since_start_ms of this DeviceCurrentState.
        :rtype: int
        """
        return self._time_since_start_ms

    @time_since_start_ms.setter
    def time_since_start_ms(self, time_since_start_ms):
        """
        Sets the time_since_start_ms of this DeviceCurrentState.


        :param time_since_start_ms: The time_since_start_ms of this DeviceCurrentState.
        :type: int
        """

        self._time_since_start_ms = time_since_start_ms

    @property
    def battery_level(self):
        """
        Gets the battery_level of this DeviceCurrentState.


        :return: The battery_level of this DeviceCurrentState.
        :rtype: float
        """
        return self._battery_level

    @battery_level.setter
    def battery_level(self, battery_level):
        """
        Sets the battery_level of this DeviceCurrentState.


        :param battery_level: The battery_level of this DeviceCurrentState.
        :type: float
        """

        self._battery_level = battery_level

    @property
    def data_connection_type(self):
        """
        Gets the data_connection_type of this DeviceCurrentState.


        :return: The data_connection_type of this DeviceCurrentState.
        :rtype: str
        """
        return self._data_connection_type

    @data_connection_type.setter
    def data_connection_type(self, data_connection_type):
        """
        Sets the data_connection_type of this DeviceCurrentState.


        :param data_connection_type: The data_connection_type of this DeviceCurrentState.
        :type: str
        """

        self._data_connection_type = data_connection_type

    @property
    def data_connection_type_detail(self):
        """
        Gets the data_connection_type_detail of this DeviceCurrentState.


        :return: The data_connection_type_detail of this DeviceCurrentState.
        :rtype: str
        """
        return self._data_connection_type_detail

    @data_connection_type_detail.setter
    def data_connection_type_detail(self, data_connection_type_detail):
        """
        Sets the data_connection_type_detail of this DeviceCurrentState.


        :param data_connection_type_detail: The data_connection_type_detail of this DeviceCurrentState.
        :type: str
        """

        self._data_connection_type_detail = data_connection_type_detail

    @property
    def gps_state(self):
        """
        Gets the gps_state of this DeviceCurrentState.


        :return: The gps_state of this DeviceCurrentState.
        :rtype: bool
        """
        return self._gps_state

    @gps_state.setter
    def gps_state(self, gps_state):
        """
        Sets the gps_state of this DeviceCurrentState.


        :param gps_state: The gps_state of this DeviceCurrentState.
        :type: bool
        """

        self._gps_state = gps_state

    @property
    def total_system_memory_usage_bytes(self):
        """
        Gets the total_system_memory_usage_bytes of this DeviceCurrentState.


        :return: The total_system_memory_usage_bytes of this DeviceCurrentState.
        :rtype: int
        """
        return self._total_system_memory_usage_bytes

    @total_system_memory_usage_bytes.setter
    def total_system_memory_usage_bytes(self, total_system_memory_usage_bytes):
        """
        Sets the total_system_memory_usage_bytes of this DeviceCurrentState.


        :param total_system_memory_usage_bytes: The total_system_memory_usage_bytes of this DeviceCurrentState.
        :type: int
        """

        self._total_system_memory_usage_bytes = total_system_memory_usage_bytes

    @property
    def disk_space_free_bytes(self):
        """
        Gets the disk_space_free_bytes of this DeviceCurrentState.


        :return: The disk_space_free_bytes of this DeviceCurrentState.
        :rtype: int
        """
        return self._disk_space_free_bytes

    @disk_space_free_bytes.setter
    def disk_space_free_bytes(self, disk_space_free_bytes):
        """
        Sets the disk_space_free_bytes of this DeviceCurrentState.


        :param disk_space_free_bytes: The disk_space_free_bytes of this DeviceCurrentState.
        :type: int
        """

        self._disk_space_free_bytes = disk_space_free_bytes

    @property
    def cpu(self):
        """
        Gets the cpu of this DeviceCurrentState.


        :return: The cpu of this DeviceCurrentState.
        :rtype: str
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """
        Sets the cpu of this DeviceCurrentState.


        :param cpu: The cpu of this DeviceCurrentState.
        :type: str
        """

        self._cpu = cpu

    @property
    def system_memory_available_bytes(self):
        """
        Gets the system_memory_available_bytes of this DeviceCurrentState.


        :return: The system_memory_available_bytes of this DeviceCurrentState.
        :rtype: float
        """
        return self._system_memory_available_bytes

    @system_memory_available_bytes.setter
    def system_memory_available_bytes(self, system_memory_available_bytes):
        """
        Sets the system_memory_available_bytes of this DeviceCurrentState.


        :param system_memory_available_bytes: The system_memory_available_bytes of this DeviceCurrentState.
        :type: float
        """

        self._system_memory_available_bytes = system_memory_available_bytes

    @property
    def system_memory_low(self):
        """
        Gets the system_memory_low of this DeviceCurrentState.


        :return: The system_memory_low of this DeviceCurrentState.
        :rtype: bool
        """
        return self._system_memory_low

    @system_memory_low.setter
    def system_memory_low(self, system_memory_low):
        """
        Sets the system_memory_low of this DeviceCurrentState.


        :param system_memory_low: The system_memory_low of this DeviceCurrentState.
        :type: bool
        """

        self._system_memory_low = system_memory_low

    @property
    def system_memory_threshold_bytes(self):
        """
        Gets the system_memory_threshold_bytes of this DeviceCurrentState.


        :return: The system_memory_threshold_bytes of this DeviceCurrentState.
        :rtype: float
        """
        return self._system_memory_threshold_bytes

    @system_memory_threshold_bytes.setter
    def system_memory_threshold_bytes(self, system_memory_threshold_bytes):
        """
        Sets the system_memory_threshold_bytes of this DeviceCurrentState.


        :param system_memory_threshold_bytes: The system_memory_threshold_bytes of this DeviceCurrentState.
        :type: float
        """

        self._system_memory_threshold_bytes = system_memory_threshold_bytes

    @property
    def application_memory_available_bytes(self):
        """
        Gets the application_memory_available_bytes of this DeviceCurrentState.


        :return: The application_memory_available_bytes of this DeviceCurrentState.
        :rtype: float
        """
        return self._application_memory_available_bytes

    @application_memory_available_bytes.setter
    def application_memory_available_bytes(self, application_memory_available_bytes):
        """
        Sets the application_memory_available_bytes of this DeviceCurrentState.


        :param application_memory_available_bytes: The application_memory_available_bytes of this DeviceCurrentState.
        :type: float
        """

        self._application_memory_available_bytes = application_memory_available_bytes

    @property
    def application_memory_max_bytes(self):
        """
        Gets the application_memory_max_bytes of this DeviceCurrentState.


        :return: The application_memory_max_bytes of this DeviceCurrentState.
        :rtype: float
        """
        return self._application_memory_max_bytes

    @application_memory_max_bytes.setter
    def application_memory_max_bytes(self, application_memory_max_bytes):
        """
        Sets the application_memory_max_bytes of this DeviceCurrentState.


        :param application_memory_max_bytes: The application_memory_max_bytes of this DeviceCurrentState.
        :type: float
        """

        self._application_memory_max_bytes = application_memory_max_bytes

    @property
    def application_memory_total_bytes(self):
        """
        Gets the application_memory_total_bytes of this DeviceCurrentState.


        :return: The application_memory_total_bytes of this DeviceCurrentState.
        :rtype: float
        """
        return self._application_memory_total_bytes

    @application_memory_total_bytes.setter
    def application_memory_total_bytes(self, application_memory_total_bytes):
        """
        Sets the application_memory_total_bytes of this DeviceCurrentState.


        :param application_memory_total_bytes: The application_memory_total_bytes of this DeviceCurrentState.
        :type: float
        """

        self._application_memory_total_bytes = application_memory_total_bytes

    @property
    def device_orientation(self):
        """
        Gets the device_orientation of this DeviceCurrentState.


        :return: The device_orientation of this DeviceCurrentState.
        :rtype: str
        """
        return self._device_orientation

    @device_orientation.setter
    def device_orientation(self, device_orientation):
        """
        Sets the device_orientation of this DeviceCurrentState.


        :param device_orientation: The device_orientation of this DeviceCurrentState.
        :type: str
        """
        allowed_values = ["unknown", "portrait", "portrait_upside_down", "landscape", "LandscapeLeft", "LandscapeRight", "FaceUp", "FaceDown", "Square"]
        if device_orientation not in allowed_values:
            raise ValueError(
                "Invalid value for `device_orientation` ({0}), must be one of {1}"
                .format(device_orientation, allowed_values)
            )

        self._device_orientation = device_orientation

    @property
    def status_bar_orientation(self):
        """
        Gets the status_bar_orientation of this DeviceCurrentState.


        :return: The status_bar_orientation of this DeviceCurrentState.
        :rtype: str
        """
        return self._status_bar_orientation

    @status_bar_orientation.setter
    def status_bar_orientation(self, status_bar_orientation):
        """
        Sets the status_bar_orientation of this DeviceCurrentState.


        :param status_bar_orientation: The status_bar_orientation of this DeviceCurrentState.
        :type: str
        """
        allowed_values = ["unknown", "portrait", "portrait_upside_down", "landscape", "LandscapeLeft", "LandscapeRight", "FaceUp", "FaceDown", "Square"]
        if status_bar_orientation not in allowed_values:
            raise ValueError(
                "Invalid value for `status_bar_orientation` ({0}), must be one of {1}"
                .format(status_bar_orientation, allowed_values)
            )

        self._status_bar_orientation = status_bar_orientation

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class NetworkPerformanceEvent(object):

    def __init__(self, timestamp_unixtime_ms=None, event_id=None, source_message_id=None, session_id=None, session_uuid=None, custom_attributes=None, location=None, device_current_state=None, http_verb=None, url=None, time_elapsed=None, bytes_in=None, bytes_out=None, response_code=None, data=None):
        """
        NetworkPerformanceEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'http_verb': 'str',
            'url': 'str',
            'time_elapsed': 'int',
            'bytes_in': 'int',
            'bytes_out': 'int',
            'response_code': 'int',
            'data': 'str'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'http_verb': 'http_verb',
            'url': 'url',
            'time_elapsed': 'time_elapsed',
            'bytes_in': 'bytes_in',
            'bytes_out': 'bytes_out',
            'response_code': 'response_code',
            'data': 'data'
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self._custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._http_verb = http_verb
        self._url = url
        self._time_elapsed = time_elapsed
        self._bytes_in = bytes_in
        self._bytes_out = bytes_out
        self._response_code = response_code
        self._data = data

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this NetworkPerformanceEvent.


        :return: The timestamp_unixtime_ms of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this NetworkPerformanceEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this NetworkPerformanceEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this NetworkPerformanceEvent.


        :return: The event_id of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this NetworkPerformanceEvent.


        :param event_id: The event_id of this NetworkPerformanceEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this NetworkPerformanceEvent.


        :return: The source_message_id of this NetworkPerformanceEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this NetworkPerformanceEvent.


        :param source_message_id: The source_message_id of this NetworkPerformanceEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this NetworkPerformanceEvent.


        :return: The session_id of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this NetworkPerformanceEvent.


        :param session_id: The session_id of this NetworkPerformanceEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this NetworkPerformanceEvent.


        :return: The session_uuid of this NetworkPerformanceEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this NetworkPerformanceEvent.


        :param session_uuid: The session_uuid of this NetworkPerformanceEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this NetworkPerformanceEvent.


        :return: The custom_attributes of this NetworkPerformanceEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this NetworkPerformanceEvent.


        :param custom_attributes: The custom_attributes of this NetworkPerformanceEvent.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this NetworkPerformanceEvent.


        :return: The location of this NetworkPerformanceEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this NetworkPerformanceEvent.


        :param location: The location of this NetworkPerformanceEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this NetworkPerformanceEvent.


        :return: The device_current_state of this NetworkPerformanceEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this NetworkPerformanceEvent.


        :param device_current_state: The device_current_state of this NetworkPerformanceEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def http_verb(self):
        """
        Gets the http_verb of this NetworkPerformanceEvent.


        :return: The http_verb of this NetworkPerformanceEvent.
        :rtype: str
        """
        return self._http_verb

    @http_verb.setter
    def http_verb(self, http_verb):
        """
        Sets the http_verb of this NetworkPerformanceEvent.


        :param http_verb: The http_verb of this NetworkPerformanceEvent.
        :type: str
        """

        self._http_verb = http_verb

    @property
    def url(self):
        """
        Gets the url of this NetworkPerformanceEvent.


        :return: The url of this NetworkPerformanceEvent.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this NetworkPerformanceEvent.


        :param url: The url of this NetworkPerformanceEvent.
        :type: str
        """

        self._url = url

    @property
    def time_elapsed(self):
        """
        Gets the time_elapsed of this NetworkPerformanceEvent.


        :return: The time_elapsed of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._time_elapsed

    @time_elapsed.setter
    def time_elapsed(self, time_elapsed):
        """
        Sets the time_elapsed of this NetworkPerformanceEvent.


        :param time_elapsed: The time_elapsed of this NetworkPerformanceEvent.
        :type: int
        """

        self._time_elapsed = time_elapsed

    @property
    def bytes_in(self):
        """
        Gets the bytes_in of this NetworkPerformanceEvent.


        :return: The bytes_in of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._bytes_in

    @bytes_in.setter
    def bytes_in(self, bytes_in):
        """
        Sets the bytes_in of this NetworkPerformanceEvent.


        :param bytes_in: The bytes_in of this NetworkPerformanceEvent.
        :type: int
        """

        self._bytes_in = bytes_in

    @property
    def bytes_out(self):
        """
        Gets the bytes_out of this NetworkPerformanceEvent.


        :return: The bytes_out of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._bytes_out

    @bytes_out.setter
    def bytes_out(self, bytes_out):
        """
        Sets the bytes_out of this NetworkPerformanceEvent.


        :param bytes_out: The bytes_out of this NetworkPerformanceEvent.
        :type: int
        """

        self._bytes_out = bytes_out

    @property
    def response_code(self):
        """
        Gets the response_code of this NetworkPerformanceEvent.


        :return: The response_code of this NetworkPerformanceEvent.
        :rtype: int
        """
        return self._response_code

    @response_code.setter
    def response_code(self, response_code):
        """
        Sets the response_code of this NetworkPerformanceEvent.


        :param response_code: The response_code of this NetworkPerformanceEvent.
        :type: int
        """

        self._response_code = response_code

    @property
    def data(self):
        """
        Gets the data of this NetworkPerformanceEvent.


        :return: The data of this NetworkPerformanceEvent.
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this NetworkPerformanceEvent.


        :param data: The data of this NetworkPerformanceEvent.
        :type: str
        """

        self._data = data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ProductAction(object):

    def __init__(self, action=None, checkout_step=None, checkout_options=None, product_action_list=None, product_list_source=None, transaction_id=None, affiliation=None, total_amount=None, tax_amount=None, shipping_amount=None, coupon_code=None, products=None):
        """
        ProductAction - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'checkout_step': 'int',
            'checkout_options': 'str',
            'product_action_list': 'str',
            'product_list_source': 'str',
            'transaction_id': 'str',
            'affiliation': 'str',
            'total_amount': 'float',
            'tax_amount': 'float',
            'shipping_amount': 'float',
            'coupon_code': 'str',
            'products': 'list[Product]'
        }

        self.attribute_map = {
            'action': 'action',
            'checkout_step': 'checkout_step',
            'checkout_options': 'checkout_options',
            'product_action_list': 'product_action_list',
            'product_list_source': 'product_list_source',
            'transaction_id': 'transaction_id',
            'affiliation': 'affiliation',
            'total_amount': 'total_amount',
            'tax_amount': 'tax_amount',
            'shipping_amount': 'shipping_amount',
            'coupon_code': 'coupon_code',
            'products': 'products'
        }

        self._action = action
        self._checkout_step = checkout_step
        self._checkout_options = checkout_options
        self._product_action_list = product_action_list
        self._product_list_source = product_list_source
        self._transaction_id = transaction_id
        self._affiliation = affiliation
        self._total_amount = total_amount
        self._tax_amount = tax_amount
        self._shipping_amount = shipping_amount
        self._coupon_code = coupon_code
        self._products = products

    @property
    def action(self):
        """
        Gets the action of this ProductAction.


        :return: The action of this ProductAction.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ProductAction.


        :param action: The action of this ProductAction.
        :type: str
        """
        allowed_values = ["unknown", "add_to_cart", "remove_from_cart", "checkout", "checkout_option", "click", "view_detail", "purchase", "refund", "add_to_wishlist", "remove_from_wish_list"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def checkout_step(self):
        """
        Gets the checkout_step of this ProductAction.


        :return: The checkout_step of this ProductAction.
        :rtype: int
        """
        return self._checkout_step

    @checkout_step.setter
    def checkout_step(self, checkout_step):
        """
        Sets the checkout_step of this ProductAction.


        :param checkout_step: The checkout_step of this ProductAction.
        :type: int
        """

        self._checkout_step = checkout_step

    @property
    def checkout_options(self):
        """
        Gets the checkout_options of this ProductAction.


        :return: The checkout_options of this ProductAction.
        :rtype: str
        """
        return self._checkout_options

    @checkout_options.setter
    def checkout_options(self, checkout_options):
        """
        Sets the checkout_options of this ProductAction.


        :param checkout_options: The checkout_options of this ProductAction.
        :type: str
        """

        self._checkout_options = checkout_options

    @property
    def product_action_list(self):
        """
        Gets the product_action_list of this ProductAction.


        :return: The product_action_list of this ProductAction.
        :rtype: str
        """
        return self._product_action_list

    @product_action_list.setter
    def product_action_list(self, product_action_list):
        """
        Sets the product_action_list of this ProductAction.


        :param product_action_list: The product_action_list of this ProductAction.
        :type: str
        """

        self._product_action_list = product_action_list

    @property
    def product_list_source(self):
        """
        Gets the product_list_source of this ProductAction.


        :return: The product_list_source of this ProductAction.
        :rtype: str
        """
        return self._product_list_source

    @product_list_source.setter
    def product_list_source(self, product_list_source):
        """
        Sets the product_list_source of this ProductAction.


        :param product_list_source: The product_list_source of this ProductAction.
        :type: str
        """

        self._product_list_source = product_list_source

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this ProductAction.


        :return: The transaction_id of this ProductAction.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this ProductAction.


        :param transaction_id: The transaction_id of this ProductAction.
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def affiliation(self):
        """
        Gets the affiliation of this ProductAction.


        :return: The affiliation of this ProductAction.
        :rtype: str
        """
        return self._affiliation

    @affiliation.setter
    def affiliation(self, affiliation):
        """
        Sets the affiliation of this ProductAction.


        :param affiliation: The affiliation of this ProductAction.
        :type: str
        """

        self._affiliation = affiliation

    @property
    def total_amount(self):
        """
        Gets the total_amount of this ProductAction.


        :return: The total_amount of this ProductAction.
        :rtype: float
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """
        Sets the total_amount of this ProductAction.


        :param total_amount: The total_amount of this ProductAction.
        :type: float
        """

        self._total_amount = total_amount

    @property
    def tax_amount(self):
        """
        Gets the tax_amount of this ProductAction.


        :return: The tax_amount of this ProductAction.
        :rtype: float
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """
        Sets the tax_amount of this ProductAction.


        :param tax_amount: The tax_amount of this ProductAction.
        :type: float
        """

        self._tax_amount = tax_amount

    @property
    def shipping_amount(self):
        """
        Gets the shipping_amount of this ProductAction.


        :return: The shipping_amount of this ProductAction.
        :rtype: float
        """
        return self._shipping_amount

    @shipping_amount.setter
    def shipping_amount(self, shipping_amount):
        """
        Sets the shipping_amount of this ProductAction.


        :param shipping_amount: The shipping_amount of this ProductAction.
        :type: float
        """

        self._shipping_amount = shipping_amount

    @property
    def coupon_code(self):
        """
        Gets the coupon_code of this ProductAction.


        :return: The coupon_code of this ProductAction.
        :rtype: str
        """
        return self._coupon_code

    @coupon_code.setter
    def coupon_code(self, coupon_code):
        """
        Sets the coupon_code of this ProductAction.


        :param coupon_code: The coupon_code of this ProductAction.
        :type: str
        """

        self._coupon_code = coupon_code

    @property
    def products(self):
        """
        Gets the products of this ProductAction.


        :return: The products of this ProductAction.
        :rtype: list[Product]
        """
        return self._products

    @products.setter
    def products(self, products):
        """
        Sets the products of this ProductAction.


        :param products: The products of this ProductAction.
        :type: list[Product]
        """

        self._products = products

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Product(object):

    def __init__(self, id=None, name=None, brand=None, category=None, variant=None, position=None, price=None, quantity=None, coupon_code=None, added_to_cart_time_ms=None, total_product_amount=None, custom_attributes=None):
        """
        Product - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'brand': 'str',
            'category': 'str',
            'variant': 'str',
            'position': 'int',
            'price': 'float',
            'quantity': 'float',
            'coupon_code': 'str',
            'added_to_cart_time_ms': 'int',
            'total_product_amount': 'float',
            'custom_attributes': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'brand': 'brand',
            'category': 'category',
            'variant': 'variant',
            'position': 'position',
            'price': 'price',
            'quantity': 'quantity',
            'coupon_code': 'coupon_code',
            'added_to_cart_time_ms': 'added_to_cart_time_ms',
            'total_product_amount': 'total_product_amount',
            'custom_attributes': 'custom_attributes'
        }

        self._id = id
        self._name = name
        self._brand = brand
        self._category = category
        self._variant = variant
        self._position = position
        self._price = price
        self._quantity = quantity
        self._coupon_code = coupon_code
        self._added_to_cart_time_ms = added_to_cart_time_ms
        self._total_product_amount = total_product_amount
        self._custom_attributes = custom_attributes

    @property
    def id(self):
        """
        Gets the id of this Product.


        :return: The id of this Product.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Product.


        :param id: The id of this Product.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Product.


        :return: The name of this Product.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Product.


        :param name: The name of this Product.
        :type: str
        """

        self._name = name

    @property
    def brand(self):
        """
        Gets the brand of this Product.


        :return: The brand of this Product.
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """
        Sets the brand of this Product.


        :param brand: The brand of this Product.
        :type: str
        """

        self._brand = brand

    @property
    def category(self):
        """
        Gets the category of this Product.


        :return: The category of this Product.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Product.


        :param category: The category of this Product.
        :type: str
        """

        self._category = category

    @property
    def variant(self):
        """
        Gets the variant of this Product.


        :return: The variant of this Product.
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """
        Sets the variant of this Product.


        :param variant: The variant of this Product.
        :type: str
        """

        self._variant = variant

    @property
    def position(self):
        """
        Gets the position of this Product.


        :return: The position of this Product.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this Product.


        :param position: The position of this Product.
        :type: int
        """

        self._position = position

    @property
    def price(self):
        """
        Gets the price of this Product.


        :return: The price of this Product.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this Product.


        :param price: The price of this Product.
        :type: float
        """

        self._price = price

    @property
    def quantity(self):
        """
        Gets the quantity of this Product.


        :return: The quantity of this Product.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this Product.


        :param quantity: The quantity of this Product.
        :type: float
        """

        self._quantity = quantity

    @property
    def coupon_code(self):
        """
        Gets the coupon_code of this Product.


        :return: The coupon_code of this Product.
        :rtype: str
        """
        return self._coupon_code

    @coupon_code.setter
    def coupon_code(self, coupon_code):
        """
        Sets the coupon_code of this Product.


        :param coupon_code: The coupon_code of this Product.
        :type: str
        """

        self._coupon_code = coupon_code

    @property
    def added_to_cart_time_ms(self):
        """
        Gets the added_to_cart_time_ms of this Product.


        :return: The added_to_cart_time_ms of this Product.
        :rtype: int
        """
        return self._added_to_cart_time_ms

    @added_to_cart_time_ms.setter
    def added_to_cart_time_ms(self, added_to_cart_time_ms):
        """
        Sets the added_to_cart_time_ms of this Product.


        :param added_to_cart_time_ms: The added_to_cart_time_ms of this Product.
        :type: int
        """

        self._added_to_cart_time_ms = added_to_cart_time_ms

    @property
    def total_product_amount(self):
        """
        Gets the total_product_amount of this Product.


        :return: The total_product_amount of this Product.
        :rtype: float
        """
        return self._total_product_amount

    @total_product_amount.setter
    def total_product_amount(self, total_product_amount):
        """
        Sets the total_product_amount of this Product.


        :param total_product_amount: The total_product_amount of this Product.
        :type: float
        """

        self._total_product_amount = total_product_amount

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this Product.


        :return: The custom_attributes of this Product.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this Product.


        :param custom_attributes: The custom_attributes of this Product.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class PushRegistrationEvent(object):

    def __init__(self, timestamp_unixtime_ms=None, event_id=None, source_message_id=None, session_id=None, session_uuid=None, custom_attributes=None, location=None, device_current_state=None, register=None, registration_token=None):
        """
        PushRegistrationEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'register': 'bool',
            'registration_token': 'str'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'register': 'register',
            'registration_token': 'registration_token'
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self._custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._register = register
        self._registration_token = registration_token

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this PushRegistrationEvent.


        :return: The timestamp_unixtime_ms of this PushRegistrationEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this PushRegistrationEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this PushRegistrationEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this PushRegistrationEvent.


        :return: The event_id of this PushRegistrationEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this PushRegistrationEvent.


        :param event_id: The event_id of this PushRegistrationEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this PushRegistrationEvent.


        :return: The source_message_id of this PushRegistrationEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this PushRegistrationEvent.


        :param source_message_id: The source_message_id of this PushRegistrationEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this PushRegistrationEvent.


        :return: The session_id of this PushRegistrationEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this PushRegistrationEvent.


        :param session_id: The session_id of this PushRegistrationEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this PushRegistrationEvent.


        :return: The session_uuid of this PushRegistrationEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this PushRegistrationEvent.


        :param session_uuid: The session_uuid of this PushRegistrationEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this PushRegistrationEvent.


        :return: The custom_attributes of this PushRegistrationEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this PushRegistrationEvent.


        :param custom_attributes: The custom_attributes of this PushRegistrationEvent.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this PushRegistrationEvent.


        :return: The location of this PushRegistrationEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this PushRegistrationEvent.


        :param location: The location of this PushRegistrationEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this PushRegistrationEvent.


        :return: The device_current_state of this PushRegistrationEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this PushRegistrationEvent.


        :param device_current_state: The device_current_state of this PushRegistrationEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def register(self):
        """
        Gets the register of this PushRegistrationEvent.


        :return: The register of this PushRegistrationEvent.
        :rtype: bool
        """
        return self._register

    @register.setter
    def register(self, register):
        """
        Sets the register of this PushRegistrationEvent.


        :param register: The register of this PushRegistrationEvent.
        :type: bool
        """

        self._register = register

    @property
    def registration_token(self):
        """
        Gets the registration_token of this PushRegistrationEvent.


        :return: The registration_token of this PushRegistrationEvent.
        :rtype: str
        """
        return self._registration_token

    @registration_token.setter
    def registration_token(self, registration_token):
        """
        Sets the registration_token of this PushRegistrationEvent.


        :param registration_token: The registration_token of this PushRegistrationEvent.
        :type: str
        """

        self._registration_token = registration_token

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class MediaInfo(object):

    def __init__(self, action=None, channel=None, metadata=None, timed_metadata=None, playback_position=None, format=None, quality=None, playback_rate=None):
        """
        MediaInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'channel': 'str',
            'metadata': 'str',
            'timed_metadata': 'str',
            'playback_position': 'float',
            'format': 'str',
            'quality': 'str',
            'playback_rate': 'float'
        }

        self.attribute_map = {
            'action': 'action',
            'channel': 'channel',
            'metadata': 'metadata',
            'timed_metadata': 'timed_metadata',
            'playback_position': 'playback_position',
            'format': 'format',
            'quality': 'quality',
            'playback_rate': 'playback_rate'
        }

        self._action = action
        self._channel = channel
        self._metadata = metadata
        self._timed_metadata = timed_metadata
        self._playback_position = playback_position
        self._format = format
        self._quality = quality
        self._playback_rate = playback_rate

    @property
    def action(self):
        """
        Gets the action of this MediaInfo.


        :return: The action of this MediaInfo.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this MediaInfo.


        :param action: The action of this MediaInfo.
        :type: str
        """
        allowed_values = ["unknown", "play", "stop", "update_playback_position", "skip", "rate"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def channel(self):
        """
        Gets the channel of this MediaInfo.


        :return: The channel of this MediaInfo.
        :rtype: str
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        """
        Sets the channel of this MediaInfo.


        :param channel: The channel of this MediaInfo.
        :type: str
        """

        self._channel = channel

    @property
    def metadata(self):
        """
        Gets the metadata of this MediaInfo.


        :return: The metadata of this MediaInfo.
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this MediaInfo.


        :param metadata: The metadata of this MediaInfo.
        :type: str
        """

        self._metadata = metadata

    @property
    def timed_metadata(self):
        """
        Gets the timed_metadata of this MediaInfo.


        :return: The timed_metadata of this MediaInfo.
        :rtype: str
        """
        return self._timed_metadata

    @timed_metadata.setter
    def timed_metadata(self, timed_metadata):
        """
        Sets the timed_metadata of this MediaInfo.


        :param timed_metadata: The timed_metadata of this MediaInfo.
        :type: str
        """

        self._timed_metadata = timed_metadata

    @property
    def playback_position(self):
        """
        Gets the playback_position of this MediaInfo.


        :return: The playback_position of this MediaInfo.
        :rtype: float
        """
        return self._playback_position

    @playback_position.setter
    def playback_position(self, playback_position):
        """
        Sets the playback_position of this MediaInfo.


        :param playback_position: The playback_position of this MediaInfo.
        :type: float
        """

        self._playback_position = playback_position

    @property
    def format(self):
        """
        Gets the format of this MediaInfo.


        :return: The format of this MediaInfo.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """
        Sets the format of this MediaInfo.


        :param format: The format of this MediaInfo.
        :type: str
        """
        allowed_values = ["unknown", "audio", "video"]
        if format not in allowed_values:
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def quality(self):
        """
        Gets the quality of this MediaInfo.


        :return: The quality of this MediaInfo.
        :rtype: str
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """
        Sets the quality of this MediaInfo.


        :param quality: The quality of this MediaInfo.
        :type: str
        """
        allowed_values = ["unknown", "low", "sd", "medium", "hd", "ultra_hd"]
        if quality not in allowed_values:
            raise ValueError(
                "Invalid value for `quality` ({0}), must be one of {1}"
                .format(quality, allowed_values)
            )

        self._quality = quality

    @property
    def playback_rate(self):
        """
        Gets the playback_rate of this MediaInfo.


        :return: The playback_rate of this MediaInfo.
        :rtype: float
        """
        return self._playback_rate

    @playback_rate.setter
    def playback_rate(self, playback_rate):
        """
        Sets the playback_rate of this MediaInfo.


        :param playback_rate: The playback_rate of this MediaInfo.
        :type: float
        """

        self._playback_rate = playback_rate

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import mparticle


class AppEvent(object):

    def __init__(self, event_name=None, custom_event_type='other',
                 timestamp_unixtime_ms=None, event_id=None,
                 source_message_id=None, session_id=None,
                 session_uuid=None, custom_attributes=None,
                 location=None, device_current_state=None,
                 media_info=None, custom_flags=None):
        """
        AppEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'custom_event_type': 'str',
            'event_name': 'str',
            'media_info': 'MediaInfo',
            'custom_flags': 'dict(str, str)'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'custom_event_type': 'custom_event_type',
            'event_name': 'event_name',
            'media_info': 'media_info',
            'custom_flags': 'custom_flags',
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self.custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._custom_event_type = custom_event_type
        if event_name is None:
            raise ValueError(
                "Event Name is required."
            )
        self._event_name = event_name
        self._media_info = media_info
        self._custom_flags = custom_flags

    @classmethod
    def create_attribution_event(cls, publisher=None, campaign=None):
        return cls(
            event_name='attribution',
            custom_event_type='attribution',
            custom_attributes={'campaign': campaign, 'publisher': publisher}
        )

    @classmethod
    def create_attribution_delete_event(cls):
        return cls(
            event_name='attribution',
            custom_event_type='attribution',
            custom_attributes={'action': 'delete'}
        )

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this AppEvent.


        :return: The timestamp_unixtime_ms of this AppEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this AppEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this AppEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this AppEvent.


        :return: The event_id of this AppEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this AppEvent.


        :param event_id: The event_id of this AppEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this AppEvent.


        :return: The source_message_id of this AppEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this AppEvent.


        :param source_message_id: The source_message_id of this AppEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this AppEvent.


        :return: The session_id of this AppEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this AppEvent.


        :param session_id: The session_id of this AppEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this AppEvent.


        :return: The session_uuid of this AppEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this AppEvent.


        :param session_uuid: The session_uuid of this AppEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this AppEvent.


        :return: The custom_attributes of this AppEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this AppEvent.


        :param custom_attributes: The custom_attributes of this AppEvent.
        :type: dict(str, str)
        """

        if not mparticle.ApiClient.validate_attribute_bag_values(custom_attributes):
            raise ValueError(
                "Invalid custom_attributes passed to AppEvent: " + str(custom_attributes))

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this AppEvent.


        :return: The location of this AppEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this AppEvent.


        :param location: The location of this AppEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this AppEvent.


        :return: The device_current_state of this AppEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this AppEvent.


        :param device_current_state: The device_current_state of this AppEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def custom_event_type(self):
        """
        Gets the custom_event_type of this AppEvent.


        :return: The custom_event_type of this AppEvent.
        :rtype: str
        """
        return self._custom_event_type

    @custom_event_type.setter
    def custom_event_type(self, custom_event_type):
        """
        Sets the custom_event_type of this AppEvent.


        :param custom_event_type: The custom_event_type of this AppEvent.
        :type: str
        """
        allowed_values = ["unknown", "navigation", "location", "search", "transaction",
                          "user_content", "user_preference", "social", "other", "attribution"]
        if custom_event_type not in allowed_values:
            raise ValueError(
                "Invalid value for `custom_event_type` ({0}), must be one of {1}"
                .format(custom_event_type, allowed_values)
            )

        self._custom_event_type = custom_event_type

    @property
    def event_name(self):
        """
        Gets the event_name of this AppEvent.


        :return: The event_name of this AppEvent.
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """
        Sets the event_name of this AppEvent.


        :param event_name: The event_name of this AppEvent.
        :type: str
        """

        self._event_name = event_name

    @property
    def media_info(self):
        """
        Gets the media_info of this AppEvent.


        :return: The media_info of this AppEvent.
        :rtype: MediaInfo
        """
        return self._media_info

    @media_info.setter
    def media_info(self, media_info):
        """
        Sets the media_info of this AppEvent.


        :param media_info: The media_info of this AppEvent.
        :type: MediaInfo
        """

        self._media_info = media_info

    @property
    def ltv_amount(self):
        """
        Gets the ltv_amount of this AppEvent.


        :return: The ltv_amount of this AppEvent.
        :rtype: int
        """
        return self._ltv_amount

    @ltv_amount.setter
    def ltv_amount(self, ltv_amount):
        """
        Sets the ltv_amount of this AppEvent.


        :param ltv_amount: The ltv_amount of this AppEvent.
        :type: int
        """
        self._ltv_amount = ltv_amount

        if self.ltv_amount is not None:
            if self._custom_attributes is None:
                self._custom_attributes = {}
            self._custom_attributes["$Amount"] = self.ltv_amount
            self._custom_attributes["MethodName"] = "LogLTVIncrease"
        elif self.custom_attributes is not None:
            self._custom_attributes.pop("$Amount", None)
            self._custom_attributes.pop("MethodName", None)

    @property
    def custom_flags(self):
        """
        Gets the custom_flags of this AppEvent.


        :return: The custom_flags of this AppEvent.
        :rtype: dict(str, str)
        """
        return self._custom_flags

    @custom_flags.setter
    def custom_flags(self, custom_flags):
        """
        Sets the custom_flags of this AppEvent.


        :param custom_flags: The custom_flags of this AppEvent.
        :type: dict(str, str)
        """

        self._custom_flags = custom_flags

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class CCPAConsentState(object):
    def __init__(self, document=None, consented=None, timestamp_unixtime_ms=None, location=None, hardware_id=None):
        """
        CCPAConsentState - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'document': 'str',
            'consented': 'bool',
            'timestamp_unixtime_ms': 'int',
            'location': 'str',
            'hardware_id': 'str'
        }

        self.attribute_map = {
            'document': 'document',
            'consented': 'consented',
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'location': 'location',
            'hardware_id': 'hardware_id'
        }

        self.document = document
        self.consented = consented
        self.timestamp_unixtime_ms = timestamp_unixtime_ms
        self.location = location
        self.hardware_id = hardware_id

    @property
    def document(self):
        """
        Gets the document of this CCPAConsentState

        :return The document of this CCPAConsentState
        :rtype str
        """
        return self._document

    @document.setter
    def document(self, document):
        """
        Sets the document of this CCPA Consent State.


        :param document: The document of this CCPA Consent State.
        :type: str
        """

        self._document = document

    @property
    def consented(self):
        """
        Gets the consented of this CCPAConsentState

        :return The consented of this CCPAConsentState
        :rtype str
        """
        return self._consented

    @consented.setter
    def consented(self, consented):
        """
        Sets the consented of this CCPA Consent State.


        :param consented: The consented of this CCPA Consent State.
        :type: str
        """

        self._consented = consented

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this CCPAConsentState

        :return The timestamp_unixtime_ms of this CCPAConsentState
        :rtype str
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this CCPA Consent State.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this CCPA Consent State.
        :type: str
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def location(self):
        """
        Gets the location of this CCPAConsentState

        :return The location of this CCPAConsentState
        :rtype str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this CCPA Consent State.


        :param location: The location of this CCPA Consent State.
        :type: str
        """

        self._location = location

    @property
    def hardware_id(self):
        """
        Gets the hardware_id of this CCPAConsentState

        :return The hardware_id of this CCPAConsentState
        :rtype str
        """
        return self._hardware_id

    @hardware_id.setter
    def hardware_id(self, hardware_id):
        """
        Sets the hardware_id of this CCPA Consent State.


        :param hardware_id: The hardware_id of this CCPA Consent State.
        :type: str
        """

        self._hardware_id = hardware_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into sdk package
from .models.api_response import ApiResponse
from .models.api_response_errors import ApiResponseErrors
from .models.app_event import AppEvent
from .models.application_information import ApplicationInformation
from .models.application_state_transition_event import ApplicationStateTransitionEvent
from .models.attribution_info import AttributionInfo
from .models.batch import Batch
from .models.breadcrumb_event import BreadcrumbEvent
from .models.ccpa_consent_state import CCPAConsentState
from .models.commerce_event import CommerceEvent
from .models.consent_state import ConsentState
from .models.crash_report_event import CrashReportEvent
from .models.device_current_state import DeviceCurrentState
from .models.device_information import DeviceInformation
from .models.event_base import EventBase
from .models.event_data import EventData
from .models.first_run_event import FirstRunEvent
from .models.gdpr_consent_state import GDPRConsentState
from .models.geo_location import GeoLocation
from .models.media_info import MediaInfo
from .models.network_performance_event import NetworkPerformanceEvent
from .models.opt_out_event import OptOutEvent
from .models.product import Product
from .models.product_action import ProductAction
from .models.product_impression import ProductImpression
from .models.profile_event import ProfileEvent
from .models.promotion import Promotion
from .models.promotion_action import PromotionAction
from .models.push_message_event import PushMessageEvent
from .models.push_registration_event import PushRegistrationEvent
from .models.screen_view_event import ScreenViewEvent
from .models.session_end_event import SessionEndEvent
from .models.session_start_event import SessionStartEvent
from .models.shopping_cart import ShoppingCart
from .models.source_information import SourceInformation
from .models.user_identities import UserIdentities
from .models.batch_context import BatchContext
from .models.data_plan_context import DataPlanContext

# import apis into sdk package
from .apis.events_api import EventsApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class PushMessageEvent(object):

    def __init__(self, timestamp_unixtime_ms=None, event_id=None, source_message_id=None, session_id=None, session_uuid=None, custom_attributes=None, location=None, device_current_state=None, push_message_token=None, push_message_type=None, message=None, network=None, push_notification_payload=None, application_state=None, action_identifier=None):
        """
        PushMessageEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'push_message_token': 'str',
            'push_message_type': 'str',
            'message': 'str',
            'network': 'str',
            'push_notification_payload': 'str',
            'application_state': 'str',
            'action_identifier': 'str'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'push_message_token': 'push_message_token',
            'push_message_type': 'push_message_type',
            'message': 'message',
            'network': 'network',
            'push_notification_payload': 'push_notification_payload',
            'application_state': 'application_state',
            'action_identifier': 'action_identifier'
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self._custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._push_message_token = push_message_token
        self._push_message_type = push_message_type
        self._message = message
        self._network = network
        self._push_notification_payload = push_notification_payload
        self._application_state = application_state
        self._action_identifier = action_identifier

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this PushMessageEvent.


        :return: The timestamp_unixtime_ms of this PushMessageEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this PushMessageEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this PushMessageEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this PushMessageEvent.


        :return: The event_id of this PushMessageEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this PushMessageEvent.


        :param event_id: The event_id of this PushMessageEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this PushMessageEvent.


        :return: The source_message_id of this PushMessageEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this PushMessageEvent.


        :param source_message_id: The source_message_id of this PushMessageEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this PushMessageEvent.


        :return: The session_id of this PushMessageEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this PushMessageEvent.


        :param session_id: The session_id of this PushMessageEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this PushMessageEvent.


        :return: The session_uuid of this PushMessageEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this PushMessageEvent.


        :param session_uuid: The session_uuid of this PushMessageEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this PushMessageEvent.


        :return: The custom_attributes of this PushMessageEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this PushMessageEvent.


        :param custom_attributes: The custom_attributes of this PushMessageEvent.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this PushMessageEvent.


        :return: The location of this PushMessageEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this PushMessageEvent.


        :param location: The location of this PushMessageEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this PushMessageEvent.


        :return: The device_current_state of this PushMessageEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this PushMessageEvent.


        :param device_current_state: The device_current_state of this PushMessageEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def push_message_token(self):
        """
        Gets the push_message_token of this PushMessageEvent.


        :return: The push_message_token of this PushMessageEvent.
        :rtype: str
        """
        return self._push_message_token

    @push_message_token.setter
    def push_message_token(self, push_message_token):
        """
        Sets the push_message_token of this PushMessageEvent.


        :param push_message_token: The push_message_token of this PushMessageEvent.
        :type: str
        """

        self._push_message_token = push_message_token

    @property
    def push_message_type(self):
        """
        Gets the push_message_type of this PushMessageEvent.


        :return: The push_message_type of this PushMessageEvent.
        :rtype: str
        """
        return self._push_message_type

    @push_message_type.setter
    def push_message_type(self, push_message_type):
        """
        Sets the push_message_type of this PushMessageEvent.


        :param push_message_type: The push_message_type of this PushMessageEvent.
        :type: str
        """
        allowed_values = ["unknown", "sent", "received", "action"]
        if push_message_type not in allowed_values:
            raise ValueError(
                "Invalid value for `push_message_type` ({0}), must be one of {1}"
                .format(push_message_type, allowed_values)
            )

        self._push_message_type = push_message_type

    @property
    def message(self):
        """
        Gets the message of this PushMessageEvent.


        :return: The message of this PushMessageEvent.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this PushMessageEvent.


        :param message: The message of this PushMessageEvent.
        :type: str
        """

        self._message = message

    @property
    def network(self):
        """
        Gets the network of this PushMessageEvent.


        :return: The network of this PushMessageEvent.
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """
        Sets the network of this PushMessageEvent.


        :param network: The network of this PushMessageEvent.
        :type: str
        """

        self._network = network

    @property
    def push_notification_payload(self):
        """
        Gets the push_notification_payload of this PushMessageEvent.


        :return: The push_notification_payload of this PushMessageEvent.
        :rtype: str
        """
        return self._push_notification_payload

    @push_notification_payload.setter
    def push_notification_payload(self, push_notification_payload):
        """
        Sets the push_notification_payload of this PushMessageEvent.


        :param push_notification_payload: The push_notification_payload of this PushMessageEvent.
        :type: str
        """

        self._push_notification_payload = push_notification_payload

    @property
    def application_state(self):
        """
        Gets the application_state of this PushMessageEvent.


        :return: The application_state of this PushMessageEvent.
        :rtype: str
        """
        return self._application_state

    @application_state.setter
    def application_state(self, application_state):
        """
        Sets the application_state of this PushMessageEvent.


        :param application_state: The application_state of this PushMessageEvent.
        :type: str
        """
        allowed_values = ["unknown", "not_running", "background", "foreground"]
        if application_state not in allowed_values:
            raise ValueError(
                "Invalid value for `application_state` ({0}), must be one of {1}"
                .format(application_state, allowed_values)
            )

        self._application_state = application_state

    @property
    def action_identifier(self):
        """
        Gets the action_identifier of this PushMessageEvent.


        :return: The action_identifier of this PushMessageEvent.
        :rtype: str
        """
        return self._action_identifier

    @action_identifier.setter
    def action_identifier(self, action_identifier):
        """
        Sets the action_identifier of this PushMessageEvent.


        :param action_identifier: The action_identifier of this PushMessageEvent.
        :type: str
        """

        self._action_identifier = action_identifier

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re
from uuid import UUID


class DeviceInformation(object):

    def __init__(self, brand=None, product=None, device=None, android_uuid=None, device_manufacturer=None, platform=None, os_version=None, device_model=None, screen_height=None, screen_width=None, screen_dpi=None, device_country=None, locale_language=None, locale_country=None, network_country=None, network_carrier=None, network_code=None, network_mobile_country_code=None, timezone_offset=None, build_identifier=None, http_header_user_agent=None, ios_advertising_id=None, push_token=None, cpu_architecture=None, is_tablet=None, push_notification_sound_enabled=None, push_notification_vibrate_enabled=None, radio_access_technology=None, supports_telephony=None, has_nfc=None, bluetooth_enabled=None, bluetooth_version=None, att_timestamp_unixtime_ms=None, att_authorization_status=None, ios_idfv=None, android_advertising_id=None):
        """
        DeviceInformation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'brand': 'str',
            'product': 'str',
            'device': 'str',
            'android_uuid': 'str',
            'device_manufacturer': 'str',
            'platform': 'str',
            'os_version': 'str',
            'device_model': 'str',
            'screen_height': 'int',
            'screen_width': 'int',
            'screen_dpi': 'int',
            'device_country': 'str',
            'locale_language': 'str',
            'locale_country': 'str',
            'network_country': 'str',
            'network_carrier': 'str',
            'network_code': 'str',
            'network_mobile_country_code': 'str',
            'timezone_offset': 'int',
            'build_identifier': 'str',
            'http_header_user_agent': 'str',
            'ios_advertising_id': 'str',
            'push_token': 'str',
            'cpu_architecture': 'str',
            'is_tablet': 'bool',
            'push_notification_sound_enabled': 'bool',
            'push_notification_vibrate_enabled': 'bool',
            'radio_access_technology': 'str',
            'supports_telephony': 'bool',
            'has_nfc': 'bool',
            'bluetooth_enabled': 'bool',
            'bluetooth_version': 'str',
            'att_timestamp_unixtime_ms': 'int',
            'att_authorization_status': 'str',
            'ios_idfv': 'str',
            'android_advertising_id': 'str'
        }

        self.attribute_map = {
            'brand': 'brand',
            'product': 'product',
            'device': 'device',
            'android_uuid': 'android_uuid',
            'device_manufacturer': 'device_manufacturer',
            'platform': 'platform',
            'os_version': 'os_version',
            'device_model': 'device_model',
            'screen_height': 'screen_height',
            'screen_width': 'screen_width',
            'screen_dpi': 'screen_dpi',
            'device_country': 'device_country',
            'locale_language': 'locale_language',
            'locale_country': 'locale_country',
            'network_country': 'network_country',
            'network_carrier': 'network_carrier',
            'network_code': 'network_code',
            'network_mobile_country_code': 'network_mobile_country_code',
            'timezone_offset': 'timezone_offset',
            'build_identifier': 'build_identifier',
            'http_header_user_agent': 'http_header_user_agent',
            'ios_advertising_id': 'ios_advertising_id',
            'push_token': 'push_token',
            'cpu_architecture': 'cpu_architecture',
            'is_tablet': 'is_tablet',
            'push_notification_sound_enabled': 'push_notification_sound_enabled',
            'push_notification_vibrate_enabled': 'push_notification_vibrate_enabled',
            'radio_access_technology': 'radio_access_technology',
            'supports_telephony': 'supports_telephony',
            'has_nfc': 'has_nfc',
            'bluetooth_enabled': 'bluetooth_enabled',
            'bluetooth_version': 'bluetooth_version',
            'att_timestamp_unixtime_ms': 'att_timestamp_unixtime_ms',
            'att_authorization_status': 'att_authorization_status',
            'ios_idfv': 'ios_idfv',
            'android_advertising_id': 'android_advertising_id'
        }

        self._brand = brand
        self._product = product
        self._device = device
        self._android_uuid = android_uuid
        self._device_manufacturer = device_manufacturer
        self._platform = platform
        self._os_version = os_version
        self._device_model = device_model
        self._screen_height = screen_height
        self._screen_width = screen_width
        self._screen_dpi = screen_dpi
        self._device_country = device_country
        self._locale_language = locale_language
        self._locale_country = locale_country
        self._network_country = network_country
        self._network_carrier = network_carrier
        self._network_code = network_code
        self._network_mobile_country_code = network_mobile_country_code
        self._timezone_offset = timezone_offset
        self._build_identifier = build_identifier
        self._http_header_user_agent = http_header_user_agent
        self.ios_advertising_id = ios_advertising_id
        self._push_token = push_token
        self._cpu_architecture = cpu_architecture
        self._is_tablet = is_tablet
        self._push_notification_sound_enabled = push_notification_sound_enabled
        self._push_notification_vibrate_enabled = push_notification_vibrate_enabled
        self._radio_access_technology = radio_access_technology
        self._supports_telephony = supports_telephony
        self._has_nfc = has_nfc
        self._bluetooth_enabled = bluetooth_enabled
        self._bluetooth_version = bluetooth_version
        self.att_timestamp_unixtime_ms = att_timestamp_unixtime_ms
        self.att_authorization_status = att_authorization_status
        self.ios_idfv = ios_idfv
        self.android_advertising_id = android_advertising_id

    def validateUUID(self, uuid_string):
        if uuid_string is not None:
            try:
                UUID(uuid_string)
            except ValueError as error:
                return error
        return None

    @property
    def brand(self):
        """
        Gets the brand of this DeviceInformation.


        :return: The brand of this DeviceInformation.
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """
        Sets the brand of this DeviceInformation.


        :param brand: The brand of this DeviceInformation.
        :type: str
        """

        self._brand = brand

    @property
    def product(self):
        """
        Gets the product of this DeviceInformation.


        :return: The product of this DeviceInformation.
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """
        Sets the product of this DeviceInformation.


        :param product: The product of this DeviceInformation.
        :type: str
        """

        self._product = product

    @property
    def device(self):
        """
        Gets the device of this DeviceInformation.


        :return: The device of this DeviceInformation.
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """
        Sets the device of this DeviceInformation.


        :param device: The device of this DeviceInformation.
        :type: str
        """

        self._device = device

    @property
    def android_uuid(self):
        """
        Gets the android_uuid of this DeviceInformation.


        :return: The android_uuid of this DeviceInformation.
        :rtype: str
        """
        return self._android_uuid

    @android_uuid.setter
    def android_uuid(self, android_uuid):
        """
        Sets the android_uuid of this DeviceInformation.


        :param android_uuid: The android_uuid of this DeviceInformation.
        :type: str
        """

        self._android_uuid = android_uuid

    @property
    def device_manufacturer(self):
        """
        Gets the device_manufacturer of this DeviceInformation.


        :return: The device_manufacturer of this DeviceInformation.
        :rtype: str
        """
        return self._device_manufacturer

    @device_manufacturer.setter
    def device_manufacturer(self, device_manufacturer):
        """
        Sets the device_manufacturer of this DeviceInformation.


        :param device_manufacturer: The device_manufacturer of this DeviceInformation.
        :type: str
        """

        self._device_manufacturer = device_manufacturer

    @property
    def platform(self):
        """
        Gets the platform of this DeviceInformation.


        :return: The platform of this DeviceInformation.
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """
        Sets the platform of this DeviceInformation.


        :param platform: The platform of this DeviceInformation.
        :type: str
        """
        allowed_values = ["Unknown", "iOS", "Android", "web", "tvOS", "roku", "out_of_band", "alexa", "smart_tv", "fire_tv", "xbox"]
        if platform not in allowed_values:
            raise ValueError(
                "Invalid value for `platform` ({0}), must be one of {1}"
                .format(platform, allowed_values)
            )

        self._platform = platform

    @property
    def os_version(self):
        """
        Gets the os_version of this DeviceInformation.


        :return: The os_version of this DeviceInformation.
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """
        Sets the os_version of this DeviceInformation.


        :param os_version: The os_version of this DeviceInformation.
        :type: str
        """

        self._os_version = os_version

    @property
    def device_model(self):
        """
        Gets the device_model of this DeviceInformation.


        :return: The device_model of this DeviceInformation.
        :rtype: str
        """
        return self._device_model

    @device_model.setter
    def device_model(self, device_model):
        """
        Sets the device_model of this DeviceInformation.


        :param device_model: The device_model of this DeviceInformation.
        :type: str
        """

        self._device_model = device_model

    @property
    def screen_height(self):
        """
        Gets the screen_height of this DeviceInformation.


        :return: The screen_height of this DeviceInformation.
        :rtype: int
        """
        return self._screen_height

    @screen_height.setter
    def screen_height(self, screen_height):
        """
        Sets the screen_height of this DeviceInformation.


        :param screen_height: The screen_height of this DeviceInformation.
        :type: int
        """

        self._screen_height = screen_height

    @property
    def screen_width(self):
        """
        Gets the screen_width of this DeviceInformation.


        :return: The screen_width of this DeviceInformation.
        :rtype: int
        """
        return self._screen_width

    @screen_width.setter
    def screen_width(self, screen_width):
        """
        Sets the screen_width of this DeviceInformation.


        :param screen_width: The screen_width of this DeviceInformation.
        :type: int
        """

        self._screen_width = screen_width

    @property
    def screen_dpi(self):
        """
        Gets the screen_dpi of this DeviceInformation.


        :return: The screen_dpi of this DeviceInformation.
        :rtype: int
        """
        return self._screen_dpi

    @screen_dpi.setter
    def screen_dpi(self, screen_dpi):
        """
        Sets the screen_dpi of this DeviceInformation.


        :param screen_dpi: The screen_dpi of this DeviceInformation.
        :type: int
        """

        self._screen_dpi = screen_dpi

    @property
    def device_country(self):
        """
        Gets the device_country of this DeviceInformation.


        :return: The device_country of this DeviceInformation.
        :rtype: str
        """
        return self._device_country

    @device_country.setter
    def device_country(self, device_country):
        """
        Sets the device_country of this DeviceInformation.


        :param device_country: The device_country of this DeviceInformation.
        :type: str
        """

        self._device_country = device_country

    @property
    def locale_language(self):
        """
        Gets the locale_language of this DeviceInformation.


        :return: The locale_language of this DeviceInformation.
        :rtype: str
        """
        return self._locale_language

    @locale_language.setter
    def locale_language(self, locale_language):
        """
        Sets the locale_language of this DeviceInformation.


        :param locale_language: The locale_language of this DeviceInformation.
        :type: str
        """

        self._locale_language = locale_language

    @property
    def locale_country(self):
        """
        Gets the locale_country of this DeviceInformation.


        :return: The locale_country of this DeviceInformation.
        :rtype: str
        """
        return self._locale_country

    @locale_country.setter
    def locale_country(self, locale_country):
        """
        Sets the locale_country of this DeviceInformation.


        :param locale_country: The locale_country of this DeviceInformation.
        :type: str
        """

        self._locale_country = locale_country

    @property
    def network_country(self):
        """
        Gets the network_country of this DeviceInformation.


        :return: The network_country of this DeviceInformation.
        :rtype: str
        """
        return self._network_country

    @network_country.setter
    def network_country(self, network_country):
        """
        Sets the network_country of this DeviceInformation.


        :param network_country: The network_country of this DeviceInformation.
        :type: str
        """

        self._network_country = network_country

    @property
    def network_carrier(self):
        """
        Gets the network_carrier of this DeviceInformation.


        :return: The network_carrier of this DeviceInformation.
        :rtype: str
        """
        return self._network_carrier

    @network_carrier.setter
    def network_carrier(self, network_carrier):
        """
        Sets the network_carrier of this DeviceInformation.


        :param network_carrier: The network_carrier of this DeviceInformation.
        :type: str
        """

        self._network_carrier = network_carrier

    @property
    def network_code(self):
        """
        Gets the network_code of this DeviceInformation.


        :return: The network_code of this DeviceInformation.
        :rtype: str
        """
        return self._network_code

    @network_code.setter
    def network_code(self, network_code):
        """
        Sets the network_code of this DeviceInformation.


        :param network_code: The network_code of this DeviceInformation.
        :type: str
        """

        self._network_code = network_code

    @property
    def network_mobile_country_code(self):
        """
        Gets the network_mobile_country_code of this DeviceInformation.


        :return: The network_mobile_country_code of this DeviceInformation.
        :rtype: str
        """
        return self._network_mobile_country_code

    @network_mobile_country_code.setter
    def network_mobile_country_code(self, network_mobile_country_code):
        """
        Sets the network_mobile_country_code of this DeviceInformation.


        :param network_mobile_country_code: The network_mobile_country_code of this DeviceInformation.
        :type: str
        """

        self._network_mobile_country_code = network_mobile_country_code

    @property
    def timezone_offset(self):
        """
        Gets the timezone_offset of this DeviceInformation.


        :return: The timezone_offset of this DeviceInformation.
        :rtype: int
        """
        return self._timezone_offset

    @timezone_offset.setter
    def timezone_offset(self, timezone_offset):
        """
        Sets the timezone_offset of this DeviceInformation.


        :param timezone_offset: The timezone_offset of this DeviceInformation.
        :type: int
        """

        self._timezone_offset = timezone_offset

    @property
    def build_identifier(self):
        """
        Gets the build_identifier of this DeviceInformation.


        :return: The build_identifier of this DeviceInformation.
        :rtype: str
        """
        return self._build_identifier

    @build_identifier.setter
    def build_identifier(self, build_identifier):
        """
        Sets the build_identifier of this DeviceInformation.


        :param build_identifier: The build_identifier of this DeviceInformation.
        :type: str
        """

        self._build_identifier = build_identifier

    @property
    def http_header_user_agent(self):
        """
        Gets the http_header_user_agent of this DeviceInformation.


        :return: The http_header_user_agent of this DeviceInformation.
        :rtype: str
        """
        return self._http_header_user_agent

    @http_header_user_agent.setter
    def http_header_user_agent(self, http_header_user_agent):
        """
        Sets the http_header_user_agent of this DeviceInformation.


        :param http_header_user_agent: The http_header_user_agent of this DeviceInformation.
        :type: str
        """

        self._http_header_user_agent = http_header_user_agent

    @property
    def ios_advertising_id(self):
        """
        Gets the ios_advertising_id of this DeviceInformation.


        :return: The ios_advertising_id of this DeviceInformation.
        :rtype: str
        """
        return self._ios_advertising_id

    @ios_advertising_id.setter
    def ios_advertising_id(self, ios_advertising_id):
        """
        Sets the ios_advertising_id of this DeviceInformation.


        :param ios_advertising_id: The ios_advertising_id of this DeviceInformation.
        :type: str
        """

        error = self.validateUUID(ios_advertising_id)
        if (error is not None):
            raise ValueError("Error: \"{0}\", while setting ios_advertising_id with value: {1}"
                .format(error, ios_advertising_id))

        self._ios_advertising_id = ios_advertising_id

    @property
    def push_token(self):
        """
        Gets the push_token of this DeviceInformation.


        :return: The push_token of this DeviceInformation.
        :rtype: str
        """
        return self._push_token

    @push_token.setter
    def push_token(self, push_token):
        """
        Sets the push_token of this DeviceInformation.


        :param push_token: The push_token of this DeviceInformation.
        :type: str
        """

        self._push_token = push_token

    @property
    def cpu_architecture(self):
        """
        Gets the cpu_architecture of this DeviceInformation.


        :return: The cpu_architecture of this DeviceInformation.
        :rtype: str
        """
        return self._cpu_architecture

    @cpu_architecture.setter
    def cpu_architecture(self, cpu_architecture):
        """
        Sets the cpu_architecture of this DeviceInformation.


        :param cpu_architecture: The cpu_architecture of this DeviceInformation.
        :type: str
        """

        self._cpu_architecture = cpu_architecture

    @property
    def is_tablet(self):
        """
        Gets the is_tablet of this DeviceInformation.


        :return: The is_tablet of this DeviceInformation.
        :rtype: bool
        """
        return self._is_tablet

    @is_tablet.setter
    def is_tablet(self, is_tablet):
        """
        Sets the is_tablet of this DeviceInformation.


        :param is_tablet: The is_tablet of this DeviceInformation.
        :type: bool
        """

        self._is_tablet = is_tablet

    @property
    def push_notification_sound_enabled(self):
        """
        Gets the push_notification_sound_enabled of this DeviceInformation.


        :return: The push_notification_sound_enabled of this DeviceInformation.
        :rtype: bool
        """
        return self._push_notification_sound_enabled

    @push_notification_sound_enabled.setter
    def push_notification_sound_enabled(self, push_notification_sound_enabled):
        """
        Sets the push_notification_sound_enabled of this DeviceInformation.


        :param push_notification_sound_enabled: The push_notification_sound_enabled of this DeviceInformation.
        :type: bool
        """

        self._push_notification_sound_enabled = push_notification_sound_enabled

    @property
    def push_notification_vibrate_enabled(self):
        """
        Gets the push_notification_vibrate_enabled of this DeviceInformation.


        :return: The push_notification_vibrate_enabled of this DeviceInformation.
        :rtype: bool
        """
        return self._push_notification_vibrate_enabled

    @push_notification_vibrate_enabled.setter
    def push_notification_vibrate_enabled(self, push_notification_vibrate_enabled):
        """
        Sets the push_notification_vibrate_enabled of this DeviceInformation.


        :param push_notification_vibrate_enabled: The push_notification_vibrate_enabled of this DeviceInformation.
        :type: bool
        """

        self._push_notification_vibrate_enabled = push_notification_vibrate_enabled

    @property
    def radio_access_technology(self):
        """
        Gets the radio_access_technology of this DeviceInformation.


        :return: The radio_access_technology of this DeviceInformation.
        :rtype: str
        """
        return self._radio_access_technology

    @radio_access_technology.setter
    def radio_access_technology(self, radio_access_technology):
        """
        Sets the radio_access_technology of this DeviceInformation.


        :param radio_access_technology: The radio_access_technology of this DeviceInformation.
        :type: str
        """

        self._radio_access_technology = radio_access_technology

    @property
    def supports_telephony(self):
        """
        Gets the supports_telephony of this DeviceInformation.


        :return: The supports_telephony of this DeviceInformation.
        :rtype: bool
        """
        return self._supports_telephony

    @supports_telephony.setter
    def supports_telephony(self, supports_telephony):
        """
        Sets the supports_telephony of this DeviceInformation.


        :param supports_telephony: The supports_telephony of this DeviceInformation.
        :type: bool
        """

        self._supports_telephony = supports_telephony

    @property
    def has_nfc(self):
        """
        Gets the has_nfc of this DeviceInformation.


        :return: The has_nfc of this DeviceInformation.
        :rtype: bool
        """
        return self._has_nfc

    @has_nfc.setter
    def has_nfc(self, has_nfc):
        """
        Sets the has_nfc of this DeviceInformation.


        :param has_nfc: The has_nfc of this DeviceInformation.
        :type: bool
        """

        self._has_nfc = has_nfc

    @property
    def bluetooth_enabled(self):
        """
        Gets the bluetooth_enabled of this DeviceInformation.


        :return: The bluetooth_enabled of this DeviceInformation.
        :rtype: bool
        """
        return self._bluetooth_enabled

    @bluetooth_enabled.setter
    def bluetooth_enabled(self, bluetooth_enabled):
        """
        Sets the bluetooth_enabled of this DeviceInformation.


        :param bluetooth_enabled: The bluetooth_enabled of this DeviceInformation.
        :type: bool
        """

        self._bluetooth_enabled = bluetooth_enabled

    @property
    def bluetooth_version(self):
        """
        Gets the bluetooth_version of this DeviceInformation.


        :return: The bluetooth_version of this DeviceInformation.
        :rtype: str
        """
        return self._bluetooth_version

    @bluetooth_version.setter
    def bluetooth_version(self, bluetooth_version):
        """
        Sets the bluetooth_version of this DeviceInformation.


        :param bluetooth_version: The bluetooth_version of this DeviceInformation.
        :type: str
        """

        self._bluetooth_version = bluetooth_version

    @property
    def att_timestamp_unixtime_ms(self):
        """
        Gets the att_timestamp_unixtime_ms of this DeviceInformation.


        :return: The att_timestamp_unixtime_ms of this DeviceInformation.
        :rtype: int
        """
        return self._att_timestamp_unixtime_ms

    @att_timestamp_unixtime_ms.setter
    def att_timestamp_unixtime_ms(self, att_timestamp_unixtime_ms):
        """
        Sets the att_timestamp_unixtime_ms of this DeviceInformation.


        :param att_timestamp_unixtime_ms: The att_timestamp_unixtime_ms of this DeviceInformation.
        :type: int
        """

        self._att_timestamp_unixtime_ms = att_timestamp_unixtime_ms

    @property
    def att_authorization_status(self):
        """
        Gets the att_authorization_status of this DeviceInformation.


        :return: The att_authorization_status of this DeviceInformation.
        :rtype: str
        """
        return self._att_authorization_status

    @att_authorization_status.setter
    def att_authorization_status(self, att_authorization_status):
        """
        Sets the att_authorization_status of this DeviceInformation.


        :param att_authorization_status: The att_authorization_status of this DeviceInformation.
        :type: str
        """
        if att_authorization_status is not None:
            allowed_values = ["authorized", "denied", "not_determined", "restricted"]
            if att_authorization_status not in allowed_values:
                raise ValueError(
                    "Invalid value for `att_authorization_status` ({0}), must be one of {1}"
                    .format(att_authorization_status, allowed_values)
                )

        self._att_authorization_status = att_authorization_status

    @property
    def ios_idfv(self):
        """
        Gets the ios_idfv of this DeviceInformation.


        :return: The ios_idfv of this DeviceInformation.
        :rtype: str
        """
        return self._ios_idfv

    @ios_idfv.setter
    def ios_idfv(self, ios_idfv):
        """
        Sets the ios_idfv of this DeviceInformation.


        :param ios_idfv: The ios_idfv of this DeviceInformation.
        :type: str
        """
        error = self.validateUUID(ios_idfv)
        if (error is not None):
            raise ValueError("Error: \"{0}\", while setting ios_idfv with value: {1}"
                .format(error, ios_idfv))

        self._ios_idfv = ios_idfv

    @property
    def android_advertising_id(self):
        """
        Gets the android_advertising_id of this DeviceInformation.


        :return: The android_advertising_id of this DeviceInformation.
        :rtype: str
        """
        return self._android_advertising_id

    @android_advertising_id.setter
    def android_advertising_id(self, android_advertising_id):
        """
        Sets the android_advertising_id of this DeviceInformation.


        :param android_advertising_id: The android_advertising_id of this DeviceInformation.
        :type: str
        """
        error = self.validateUUID(android_advertising_id)
        if (error is not None):
            raise ValueError("Error: \"{0}\", while setting android_advertising_id with value: {1}"
                .format(error, android_advertising_id))

        self._android_advertising_id = android_advertising_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import mparticle
from mparticle.rest import ApiException
from mparticle.models.app_event import AppEvent


class TestAppEvent(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAppEvent(self):
        event = mparticle.models.app_event.AppEvent(
            event_name='test event',
            custom_event_type='transaction',
            custom_attributes={
                'example attribute key': 'example attribute value'}
        )
        self.assertEqual('test event', event.event_name)
        self.assertEqual('transaction', event.custom_event_type)
        self.assertEqual('example attribute value',
                         event.custom_attributes['example attribute key'])

    def testAppEventAttributeValues(self):
        with self.assertRaises(ValueError):
            event = mparticle.models.app_event.AppEvent(
                event_name='test event',
                custom_event_type='transaction',
                custom_attributes={'example attribute key': ['something']}
            )

        event = mparticle.models.app_event.AppEvent(
            event_name='test event',
            custom_event_type='transaction',
            custom_attributes=None
        )
        with self.assertRaises(ValueError):
            event.custom_attributes = {'example attribute key': ['something']}

    def testAttributionEvent(self):
        event = mparticle.models.app_event.AppEvent.create_attribution_event(
            u'this is a publisher', 'this is a campaign')
        self.assertEqual('attribution', event.custom_event_type)
        self.assertEqual('attribution', event.event_name)
        self.assertEqual('this is a campaign',
                         event.custom_attributes['campaign'])
        self.assertEqual(u'this is a publisher',
                         event.custom_attributes['publisher'])

    def testAttributionDeleteEvent(self):
        event = mparticle.models.app_event.AppEvent.create_attribution_delete_event()
        self.assertEqual('attribution', event.custom_event_type)
        self.assertEqual('attribution', event.event_name)
        self.assertEqual('delete', event.custom_attributes['action'])
        self.assertFalse('campaign' in event.custom_attributes)
        self.assertFalse('publisher' in event.custom_attributes)

    def testAppEventCustomFlags(self):
        custom_flags = {
            "foo": 'bar',
            'answer': 42,
            'arrays': [
                'foo', 'bar', 'baz'
            ]
        }

        event = mparticle.models.app_event.AppEvent(
            event_name='Test Custom flags',
            custom_flags=custom_flags)

        self.assertEqual("bar", event.custom_flags.get('foo'))
        self.assertEqual(42, event.custom_flags.get('answer'))
        self.assertEqual(
            ['foo', 'bar', 'baz'],
            event.custom_flags.get('arrays'))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class CrashReportEvent(object):

    def __init__(self, timestamp_unixtime_ms=None, event_id=None, source_message_id=None, session_id=None, session_uuid=None, custom_attributes=None, location=None, device_current_state=None, breadcrumbs=None, class_name=None, severity=None, message=None, stack_trace=None, exception_handled=None, topmost_context=None, pl_crash_report_file_base64=None, ios_image_base_address=None, ios_image_size=None, session_number=None):
        """
        CrashReportEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'breadcrumbs': 'list[BreadcrumbEvent]',
            'class_name': 'str',
            'severity': 'str',
            'message': 'str',
            'stack_trace': 'str',
            'exception_handled': 'bool',
            'topmost_context': 'str',
            'pl_crash_report_file_base64': 'str',
            'ios_image_base_address': 'int',
            'ios_image_size': 'int',
            'session_number': 'int'
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'breadcrumbs': 'breadcrumbs',
            'class_name': 'class_name',
            'severity': 'severity',
            'message': 'message',
            'stack_trace': 'stack_trace',
            'exception_handled': 'exception_handled',
            'topmost_context': 'topmost_context',
            'pl_crash_report_file_base64': 'pl_crash_report_file_base64',
            'ios_image_base_address': 'ios_image_base_address',
            'ios_image_size': 'ios_image_size',
            'session_number': 'session_number'
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self._custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._breadcrumbs = breadcrumbs
        self._class_name = class_name
        self._severity = severity
        self._message = message
        self._stack_trace = stack_trace
        self._exception_handled = exception_handled
        self._topmost_context = topmost_context
        self._pl_crash_report_file_base64 = pl_crash_report_file_base64
        self._ios_image_base_address = ios_image_base_address
        self._ios_image_size = ios_image_size
        self._session_number = session_number

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this CrashReportEvent.


        :return: The timestamp_unixtime_ms of this CrashReportEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this CrashReportEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this CrashReportEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this CrashReportEvent.


        :return: The event_id of this CrashReportEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this CrashReportEvent.


        :param event_id: The event_id of this CrashReportEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this CrashReportEvent.


        :return: The source_message_id of this CrashReportEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this CrashReportEvent.


        :param source_message_id: The source_message_id of this CrashReportEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this CrashReportEvent.


        :return: The session_id of this CrashReportEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this CrashReportEvent.


        :param session_id: The session_id of this CrashReportEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this CrashReportEvent.


        :return: The session_uuid of this CrashReportEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this CrashReportEvent.


        :param session_uuid: The session_uuid of this CrashReportEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this CrashReportEvent.


        :return: The custom_attributes of this CrashReportEvent.
        :rtype: dict(str, str)
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this CrashReportEvent.


        :param custom_attributes: The custom_attributes of this CrashReportEvent.
        :type: dict(str, str)
        """

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this CrashReportEvent.


        :return: The location of this CrashReportEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this CrashReportEvent.


        :param location: The location of this CrashReportEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this CrashReportEvent.


        :return: The device_current_state of this CrashReportEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this CrashReportEvent.


        :param device_current_state: The device_current_state of this CrashReportEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def breadcrumbs(self):
        """
        Gets the breadcrumbs of this CrashReportEvent.


        :return: The breadcrumbs of this CrashReportEvent.
        :rtype: list[BreadcrumbEvent]
        """
        return self._breadcrumbs

    @breadcrumbs.setter
    def breadcrumbs(self, breadcrumbs):
        """
        Sets the breadcrumbs of this CrashReportEvent.


        :param breadcrumbs: The breadcrumbs of this CrashReportEvent.
        :type: list[BreadcrumbEvent]
        """

        self._breadcrumbs = breadcrumbs

    @property
    def class_name(self):
        """
        Gets the class_name of this CrashReportEvent.


        :return: The class_name of this CrashReportEvent.
        :rtype: str
        """
        return self._class_name

    @class_name.setter
    def class_name(self, class_name):
        """
        Sets the class_name of this CrashReportEvent.


        :param class_name: The class_name of this CrashReportEvent.
        :type: str
        """

        self._class_name = class_name

    @property
    def severity(self):
        """
        Gets the severity of this CrashReportEvent.


        :return: The severity of this CrashReportEvent.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this CrashReportEvent.


        :param severity: The severity of this CrashReportEvent.
        :type: str
        """

        self._severity = severity

    @property
    def message(self):
        """
        Gets the message of this CrashReportEvent.


        :return: The message of this CrashReportEvent.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this CrashReportEvent.


        :param message: The message of this CrashReportEvent.
        :type: str
        """

        self._message = message

    @property
    def stack_trace(self):
        """
        Gets the stack_trace of this CrashReportEvent.


        :return: The stack_trace of this CrashReportEvent.
        :rtype: str
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """
        Sets the stack_trace of this CrashReportEvent.


        :param stack_trace: The stack_trace of this CrashReportEvent.
        :type: str
        """

        self._stack_trace = stack_trace

    @property
    def exception_handled(self):
        """
        Gets the exception_handled of this CrashReportEvent.


        :return: The exception_handled of this CrashReportEvent.
        :rtype: bool
        """
        return self._exception_handled

    @exception_handled.setter
    def exception_handled(self, exception_handled):
        """
        Sets the exception_handled of this CrashReportEvent.


        :param exception_handled: The exception_handled of this CrashReportEvent.
        :type: bool
        """

        self._exception_handled = exception_handled

    @property
    def topmost_context(self):
        """
        Gets the topmost_context of this CrashReportEvent.


        :return: The topmost_context of this CrashReportEvent.
        :rtype: str
        """
        return self._topmost_context

    @topmost_context.setter
    def topmost_context(self, topmost_context):
        """
        Sets the topmost_context of this CrashReportEvent.


        :param topmost_context: The topmost_context of this CrashReportEvent.
        :type: str
        """

        self._topmost_context = topmost_context

    @property
    def pl_crash_report_file_base64(self):
        """
        Gets the pl_crash_report_file_base64 of this CrashReportEvent.


        :return: The pl_crash_report_file_base64 of this CrashReportEvent.
        :rtype: str
        """
        return self._pl_crash_report_file_base64

    @pl_crash_report_file_base64.setter
    def pl_crash_report_file_base64(self, pl_crash_report_file_base64):
        """
        Sets the pl_crash_report_file_base64 of this CrashReportEvent.


        :param pl_crash_report_file_base64: The pl_crash_report_file_base64 of this CrashReportEvent.
        :type: str
        """

        self._pl_crash_report_file_base64 = pl_crash_report_file_base64

    @property
    def ios_image_base_address(self):
        """
        Gets the ios_image_base_address of this CrashReportEvent.


        :return: The ios_image_base_address of this CrashReportEvent.
        :rtype: int
        """
        return self._ios_image_base_address

    @ios_image_base_address.setter
    def ios_image_base_address(self, ios_image_base_address):
        """
        Sets the ios_image_base_address of this CrashReportEvent.


        :param ios_image_base_address: The ios_image_base_address of this CrashReportEvent.
        :type: int
        """

        self._ios_image_base_address = ios_image_base_address

    @property
    def ios_image_size(self):
        """
        Gets the ios_image_size of this CrashReportEvent.


        :return: The ios_image_size of this CrashReportEvent.
        :rtype: int
        """
        return self._ios_image_size

    @ios_image_size.setter
    def ios_image_size(self, ios_image_size):
        """
        Sets the ios_image_size of this CrashReportEvent.


        :param ios_image_size: The ios_image_size of this CrashReportEvent.
        :type: int
        """

        self._ios_image_size = ios_image_size

    @property
    def session_number(self):
        """
        Gets the session_number of this CrashReportEvent.


        :return: The session_number of this CrashReportEvent.
        :rtype: int
        """
        return self._session_number

    @session_number.setter
    def session_number(self, session_number):
        """
        Sets the session_number of this CrashReportEvent.


        :param session_number: The session_number of this CrashReportEvent.
        :type: int
        """

        self._session_number = session_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
